Struct Cgcr
#[repr(transparent)]pub struct Cgcr(pub u32);Expand description
GFXTIM clock generator configuration register.
Tuple Fields
0: u32Implementations
impl Cgcr
impl Cgcr
pub const fn set_lcs(&mut self, val: Lcs)
pub const fn set_lcs(&mut self, val: Lcs)
line clock source This field configures the line clock source.
pub const fn lcccs(&self) -> bool
pub const fn lcccs(&self) -> bool
line clock counter clock source This bit configures the clock source for the line clock counter.
pub const fn set_lcccs(&mut self, val: bool)
pub const fn set_lcccs(&mut self, val: bool)
line clock counter clock source This bit configures the clock source for the line clock counter.
pub const fn lccfr(&self) -> bool
pub const fn lccfr(&self) -> bool
line clock counter force reload This bit forces line clock counter reload.
pub const fn set_lccfr(&mut self, val: bool)
pub const fn set_lccfr(&mut self, val: bool)
line clock counter force reload This bit forces line clock counter reload.
pub const fn lcchrs(&self) -> Lcchrs
pub const fn lcchrs(&self) -> Lcchrs
line clock counter hardware reload source This field configures the hardware reload source for the line clock counter.
pub const fn set_lcchrs(&mut self, val: Lcchrs)
pub const fn set_lcchrs(&mut self, val: Lcchrs)
line clock counter hardware reload source This field configures the hardware reload source for the line clock counter.
pub const fn set_fcs(&mut self, val: Fcs)
pub const fn set_fcs(&mut self, val: Fcs)
frame clock source This field configures the frame clock source.
pub const fn fcccs(&self) -> Fcccs
pub const fn fcccs(&self) -> Fcccs
frame clock counter clock source This field configures the clock source for the frame clock counter.
pub const fn set_fcccs(&mut self, val: Fcccs)
pub const fn set_fcccs(&mut self, val: Fcccs)
frame clock counter clock source This field configures the clock source for the frame clock counter.
pub const fn fccfr(&self) -> bool
pub const fn fccfr(&self) -> bool
frame clock counter force reload This bit forces frame clock counter reload.
pub const fn set_fccfr(&mut self, val: bool)
pub const fn set_fccfr(&mut self, val: bool)
frame clock counter force reload This bit forces frame clock counter reload.
pub const fn fcchrs(&self) -> Fcchrs
pub const fn fcchrs(&self) -> Fcchrs
frame- -clock counter hardware reload source This field configures the hardware reload source for the frame- -clock counter.
pub const fn set_fcchrs(&mut self, val: Fcchrs)
pub const fn set_fcchrs(&mut self, val: Fcchrs)
frame- -clock counter hardware reload source This field configures the hardware reload source for the frame- -clock counter.