stm32-metapac

Crates

git

Versions

stm32u5f7vj

Flavors

Isr

Struct Isr 

#[repr(transparent)]
pub struct Isr(pub u32);
GFXTIM interrupt status register.

Tuple Fields

0: u32

Implementations



impl Isr

pub const fn afcof(&self) -> bool

absolute frame counter overflow flag This bit indicates an overflow occurred on the absolute frame counter.

pub const fn set_afcof(&mut self, val: bool)

absolute frame counter overflow flag This bit indicates an overflow occurred on the absolute frame counter.

pub const fn alcof(&self) -> bool

absolute line counter overflow flag This bit indicates an overflow occurred on the absolute line counter.

pub const fn set_alcof(&mut self, val: bool)

absolute line counter overflow flag This bit indicates an overflow occurred on the absolute line counter.

pub const fn tef(&self) -> bool

tearing-effect flag This bit indicates a tearing effect event occurred.

pub const fn set_tef(&mut self, val: bool)

tearing-effect flag This bit indicates a tearing effect event occurred.

pub const fn afcc1f(&self) -> bool

absolute frame counter compare 1 flag This bit indicates match on compare 1 of the absolute frame counter.

pub const fn set_afcc1f(&mut self, val: bool)

absolute frame counter compare 1 flag This bit indicates match on compare 1 of the absolute frame counter.

pub const fn alcc1f(&self) -> bool

absolute line counter compare 1 flag This bit indicates match on compare 1 of the absolute line counter.

pub const fn set_alcc1f(&mut self, val: bool)

absolute line counter compare 1 flag This bit indicates match on compare 1 of the absolute line counter.

pub const fn alcc2f(&self) -> bool

absolute line counter compare 2 flag This bit indicates match on compare 2 of the absolute line counter.

pub const fn set_alcc2f(&mut self, val: bool)

absolute line counter compare 2 flag This bit indicates match on compare 2 of the absolute line counter.

pub const fn rfc1rf(&self) -> bool

relative frame counter 1 reload flag This bit indicates relative frame counter 1 has been reloaded.

pub const fn set_rfc1rf(&mut self, val: bool)

relative frame counter 1 reload flag This bit indicates relative frame counter 1 has been reloaded.

pub const fn rfc2rf(&self) -> bool

relative frame counter 2 reload flag This bit indicates relative frame counter 2 has been reloaded.

pub const fn set_rfc2rf(&mut self, val: bool)

relative frame counter 2 reload flag This bit indicates relative frame counter 2 has been reloaded.

pub const fn ev1f(&self) -> bool

event 1 flag This bit indicates a complex event 1 occurred.

pub const fn set_ev1f(&mut self, val: bool)

event 1 flag This bit indicates a complex event 1 occurred.

pub const fn ev2f(&self) -> bool

event 2 flag This bit indicates a complex event 2 occurred.

pub const fn set_ev2f(&mut self, val: bool)

event 2 flag This bit indicates a complex event 2 occurred.

pub const fn ev3f(&self) -> bool

event 3 flag This bit indicates a complex event 3 occurred.

pub const fn set_ev3f(&mut self, val: bool)

event 3 flag This bit indicates a complex event 3 occurred.

pub const fn ev4f(&self) -> bool

event 4 flag This bit indicates a complex event 4 occurred.

pub const fn set_ev4f(&mut self, val: bool)

event 4 flag This bit indicates a complex event 4 occurred.

pub const fn wdgaf(&self) -> bool

watchdog alarm flag This bit indicates that a graphic watchdog alarm occurred.

pub const fn set_wdgaf(&mut self, val: bool)

watchdog alarm flag This bit indicates that a graphic watchdog alarm occurred.

pub const fn wdgpf(&self) -> bool

watchdog pre-alarm flag This bit indicates that a graphic watchdog pre-alarm occurred.

pub const fn set_wdgpf(&mut self, val: bool)

watchdog pre-alarm flag This bit indicates that a graphic watchdog pre-alarm occurred.